==> java-sdk-4.2.0-sources.jar: com/baidu/aip/nlp/NlpConsts.java <==
/*
 * Copyright 2017 Baidu, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.baidu.aip.nlp;

public class NlpConsts {

    static final String LEXER = "https://aip.baidubce.com/rpc/2.0/nlp/v1/lexer";

    static final String LEXER_CUSTOM = "https://aip.baidubce.com/rpc/2.0/nlp/v1/lexer_custom";

    static final String DEP_PARSER = "https://aip.baidubce.com/rpc/2.0/nlp/v1/depparser";

    static final String WORD_EMBEDDING = "https://aip.baidubce.com/rpc/2.0/nlp/v2/word_emb_vec";

    static final String DNNLM_CN = "https://aip.baidubce.com/rpc/2.0/nlp/v2/dnnlm_cn";

    static final String WORD_SIM_EMBEDDING = "https://aip.baidubce.com/rpc/2.0/nlp/v2/word_emb_sim";

    static final String SIMNET = "https://aip.baidubce.com/rpc/2.0/nlp/v2/simnet";

    static final String COMMENT_TAG = "https://aip.baidubce.com/rpc/2.0/nlp/v2/comment_tag";

    static final String SENTIMENT_CLASSIFY = "https://aip.baidubce.com/rpc/2.0/nlp/v1/sentiment_classify";

    static final String KEYWORD = "https://aip.baidubce.com/rpc/2.0/nlp/v1/keyword";

    static final String TOPIC = "https://aip.baidubce.com/rpc/2.0/nlp/v1/topic";

}

==> java-sdk-4.4.1-sources.jar: com/baidu/aip/nlp/NlpConsts.java <==
/*
 * Copyright 2017 Baidu, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */

package com.baidu.aip.nlp;

public class NlpConsts {

    static final String LEXER = "https://aip.baidubce.com/rpc/2.0/nlp/v1/lexer";

    static final String LEXER_CUSTOM = "https://aip.baidubce.com/rpc/2.0/nlp/v1/lexer_custom";

    static final String DEP_PARSER = "https://aip.baidubce.com/rpc/2.0/nlp/v1/depparser";

    static final String WORD_EMBEDDING = "https://aip.baidubce.com/rpc/2.0/nlp/v2/word_emb_vec";

    static final String DNNLM_CN = "https://aip.baidubce.com/rpc/2.0/nlp/v2/dnnlm_cn";

    static final String WORD_SIM_EMBEDDING = "https://aip.baidubce.com/rpc/2.0/nlp/v2/word_emb_sim";

    static final String SIMNET = "https://aip.baidubce.com/rpc/2.0/nlp/v2/simnet";

    static final String COMMENT_TAG = "https://aip.baidubce.com/rpc/2.0/nlp/v2/comment_tag";

    static final String SENTIMENT_CLASSIFY = "https://aip.baidubce.com/rpc/2.0/nlp/v1/sentiment_classify";

    static final String KEYWORD = "https://aip.baidubce.com/rpc/2.0/nlp/v1/keyword";

    static final String TOPIC = "https://aip.baidubce.com/rpc/2.0/nlp/v1/topic";

    static final String ECNET = "https://aip.baidubce.com/rpc/2.0/nlp/v1/ecnet";

    static final String EMOTION = "https://aip.baidubce.com/rpc/2.0/nlp/v1/emotion";

}
